@@ -46,6 +46,7 @@ def echo(message):
     print(str(message))
 
 
+@mock.patch("fedora_messaging.config.conf.setup_logging", mock.Mock())
 class BaseCliTests(TestCase):
     """Unit tests for the base command of the CLI."""
 
@@ -57,6 +58,7 @@ class BaseCliTests(TestCase):
 
 
 @mock.patch("fedora_messaging.cli.reactor", mock.Mock())
+@mock.patch("fedora_messaging.config.conf.setup_logging", mock.Mock())
 class ConsumeCliTests(TestCase):
     """Unit tests for the 'consume' command of the CLI."""
 
@@ -97,7 +99,7 @@ class ConsumeCliTests(TestCase):
         """Assert a bad configuration file is reported."""
         expected_err = (
             "Error: Invalid value: Configuration error: Failed to parse"
-            " {}: error at line 1, column 1".format(BAD_CONF)
+            " {}: Invalid value (at line 1, column 20)".format(BAD_CONF)
         )
         result = self.runner.invoke(cli.cli, ["--conf=" + BAD_CONF, "consume"])
         self.assertEqual(2, result.exit_code)
@@ -524,6 +526,7 @@ class CallbackFromFilesytem(TestCase):
         )
 
 
+@mock.patch("fedora_messaging.config.conf.setup_logging", mock.Mock())
 class PublishCliTests(TestCase):
     """Unit tests for the 'publish' command of the CLI."""
 
@@ -668,6 +671,7 @@ class PublishCliTests(TestCase):
         self.assertEqual(1, result.exit_code)
 
 
+@mock.patch("fedora_messaging.config.conf.setup_logging", mock.Mock())
 class RecordCliTests(TestCase):
     """Unit tests for the 'record' command of the CLI."""
 
@@ -732,7 +736,7 @@ class RecorderClassTests(TestCase):
             '{"body": {"test_key1": "test_value1"}, "headers"'
             ': {"fedora_messaging_schema": "base.message", "fedora_messaging_severity": 20, '
             '"sent-at": "2018-11-18T10:11:41+00:00"}, "id": "273ed91d-b8b5-487a-9576-95b9fbdf3eec"'
-            ', "queue": null, "topic": "test_topic1"}\n'
+            ', "priority": 0, "queue": null, "topic": "test_topic1"}\n'
         )
 
         with self.assertRaises(exceptions.HaltConsumer) as cm:
@@ -744,7 +748,8 @@ class RecorderClassTests(TestCase):
             '{"body": {"test_key2": "test_value2"}, "headers": '
             '{"fedora_messaging_schema": "base.message", "fedora_messaging_severity": '
             '20, "sent-at": "2018-11-18T10:11:41+00:00"}, "id": '
-            '"273ed91d-b8b5-487a-9576-95b9fbdf3eec", "queue": null, "topic": "test_topic2"}\n'
+            '"273ed91d-b8b5-487a-9576-95b9fbdf3eec", "priority": 0, "queue": null, '
+            '"topic": "test_topic2"}\n'
         )
 
     def test_recorded_messages_dumps_failed(self):
