@@ -22,13 +22,15 @@ from fedora_messaging import config as msg_config
 from fedora_messaging.exceptions import ConfigurationException
 
 
-full_config = """
+full_config = b"""
 amqp_url = "amqp://guest:guest@rabbit-server1:5672/%2F"
 
 publish_exchange = "special_exchange"
 
 topic_prefix = ""
 
+publish_priority = 42
+
 callback = "fedora_messaging.examples:print_msg"
 
 bindings = [
@@ -83,9 +85,9 @@ handlers = ["console"]
 level = "DEBUG"
 handlers = ["console"]
 """
-empty_config = '# publish_exchange = "special_exchange"'
-partial_config = 'publish_exchange = "special_exchange"'
-malformed_config = 'publish_exchange = "special_exchange'  # missing close quote
+empty_config = b'# publish_exchange = "special_exchange"'
+partial_config = b'publish_exchange = "special_exchange"'
+malformed_config = b'publish_exchange = "special_exchange'  # missing close quote
 
 
 class TestObj:
@@ -209,7 +211,7 @@ class LoadTests(TestCase):
         )
 
     @mock.patch(
-        "fedora_messaging.config.open", mock.mock_open(read_data='bad_key = "val"')
+        "fedora_messaging.config.open", mock.mock_open(read_data=b'bad_key = "val"')
     )
     @mock.patch("fedora_messaging.config.os.path.exists", return_value=True)
     def test_override_client_props(self, mock_exists):
@@ -218,13 +220,13 @@ class LoadTests(TestCase):
         for key in ("version", "information", "product"):
             with mock.patch(
                 "fedora_messaging.config.open",
-                mock.mock_open(read_data=conf.format(key)),
+                mock.mock_open(read_data=conf.format(key).encode("utf-8")),
             ):
                 config = msg_config.LazyConfig()
                 self.assertRaises(ConfigurationException, config.load_config)
 
     @mock.patch(
-        "fedora_messaging.config.open", mock.mock_open(read_data='bad_key = "val"')
+        "fedora_messaging.config.open", mock.mock_open(read_data=b'bad_key = "val"')
     )
     @mock.patch("fedora_messaging.config.os.path.exists", return_value=True)
     def test_invalid_key(self, mock_exists):
@@ -232,17 +234,19 @@ class LoadTests(TestCase):
         config = msg_config.LazyConfig()
         self.assertRaises(ConfigurationException, config.load_config)
 
-    @mock.patch("fedora_messaging.config.open", mock.mock_open(read_data="Ni!"))
+    @mock.patch("fedora_messaging.config.open", mock.mock_open(read_data=b"Ni!"))
     @mock.patch("fedora_messaging.config.os.path.exists", return_value=True)
     def test_bad_config_file(self, mock_exists):
         """Assert an invalid TOML file raises a ConfigurationException."""
         with self.assertRaises(ConfigurationException) as cm:
             msg_config.LazyConfig().load_config()
         error = (
-            "Failed to parse /etc/fedora-messaging/config.toml: error at line 1, column 3: "
-            "Found invalid character in key name: '!'. Try quoting the key name."
+            "Failed to parse /etc/fedora-messaging/config.toml: "
+            "Expected '=' after a key in a key/value pair (at line 1, column 3)"
         )
-        self.assertEqual(error, cm.exception.message)
+        # older tomli version used in Python 3.6 uses double-quotes
+        error_old = error.replace("'", '"')
+        self.assertIn(cm.exception.message, (error, error_old))
 
     @mock.patch(
         "fedora_messaging.config.open", mock.mock_open(read_data=partial_config)
@@ -275,6 +279,7 @@ class LoadTests(TestCase):
             },
             topic_prefix="",
             publish_exchange="special_exchange",
+            publish_priority=42,
             passive_declares=False,
             exchanges={
                 "custom_exchange": {
@@ -418,6 +423,7 @@ class LoadTests(TestCase):
             "Loading configuration from /etc/fedora-messaging/config.toml"
         )
 
+    @mock.patch("fedora_messaging.config.logging.config.dictConfig", mock.Mock())
     @mock.patch("fedora_messaging.config.open", mock.mock_open(read_data=empty_config))
     @mock.patch("fedora_messaging.config._log", autospec=True)
     @mock.patch("fedora_messaging.config.os.path.exists", return_value=True)
